@@ -12,7 +12,7 @@ from asyncio import Semaphore
 from dataclasses import dataclass
 from typing import Mapping, Optional, Any
 
-import furl as furl
+import yarl
 from aiohttp import ClientSession, BasicAuth
 from async_tools import AsyncOnStop, DummyAsyncContextManager
 from init_helpers.custom_json import custom_dumps, Jsonable
@@ -68,9 +68,8 @@ class HttpServerConnector(AsyncOnStop):
         await self._requester._on_stop()
 
     def _get_url(self, path: str) -> str:
-        location_furl = furl.furl(self.config.url) / path
-        location_furl.path.normalize()
-        return location_furl.url
+        url = yarl.URL(self.config.url) / path.lstrip('/')
+        return str(url)
 
     async def post_json(self, path: str, payload: Jsonable, url_query: MultiMapping = None,
                         headers: Optional[Mapping[str, str]] = None, auth: Optional[BasicAuth] = None,
